Changelog
=========

1.2.3 (xx.xx.xx) IN DEVELOPMENT
---------------------------------


1.2.2 (06.07.2016)
------------------

 * Added this changelog :) (Andy Babic)
 * Added `WAGTAILMENUS_SECTION_ROOT_DEPTH` setting support, for more consistent identification of 'section root' pages (Andy Babic)


